#[repr(transparent)]pub struct Match(pub u32);Expand description
RTC match register
Tuple Fields
0: u32Implementations
Sourceimpl Match
impl Match
Sourcepub const fn matval(&self) -> u32
pub const fn matval(&self) -> u32
Contains the match value against which the 1 Hz RTC timer will be compared to set the alarm flag RTC_ALARM and generate an alarm interrupt/wake-up if enabled.
Sourcepub const fn set_matval(&mut self, val: u32)
pub const fn set_matval(&mut self, val: u32)
Contains the match value against which the 1 Hz RTC timer will be compared to set the alarm flag RTC_ALARM and generate an alarm interrupt/wake-up if enabled.