#[repr(transparent)]pub struct Subsec(pub u32);Expand description
Sub-second counter register
Tuple Fields
0: u32Implementations
Sourceimpl Subsec
impl Subsec
Sourcepub const fn subsec(&self) -> u16
pub const fn subsec(&self) -> u16
A read reflects the current value of the 32KHz sub-second counter. This counter is cleared whenever the SUBSEC_ENA bit in the RTC_CONTROL register is low. Up-counting at a 32KHz rate commences at the start of the next one-second interval after the SUBSEC_ENA bit is set. This counter must be re-enabled after exiting deep power-down mode or after the main RTC module is disabled and re-enabled. On modules not equipped with a sub-second counter, this register will read-back as all zeroes.
Sourcepub const fn set_subsec(&mut self, val: u16)
pub const fn set_subsec(&mut self, val: u16)
A read reflects the current value of the 32KHz sub-second counter. This counter is cleared whenever the SUBSEC_ENA bit in the RTC_CONTROL register is low. Up-counting at a 32KHz rate commences at the start of the next one-second interval after the SUBSEC_ENA bit is set. This counter must be re-enabled after exiting deep power-down mode or after the main RTC module is disabled and re-enabled. On modules not equipped with a sub-second counter, this register will read-back as all zeroes.